@@ -2,6 +2,7 @@
 # live images are specified with
 # root=live:CDLABEL=label
 # root=live:AOEINTERFACE=name
+type getOverlayBaseDirectory >/dev/null 2>&1 || . /lib/kiwi-live-lib.sh
 
 [ -z "${root}" ] && root=$(getarg root=)
 
@@ -33,8 +34,10 @@ info "root was ${liveroot}, is now ${root}"
 # make sure that init doesn't complain
 [ -z "${root}" ] && root="live"
 
-wait_for_dev -n /run/rootfsbase
-wait_for_dev -n /run/overlayfs/rw
-wait_for_dev -n /run/overlayfs/work
+OVERLAY_BASE="$(getOverlayBaseDirectory)"
+
+wait_for_dev -n "${OVERLAY_BASE}/rootfsbase"
+wait_for_dev -n "${OVERLAY_BASE}/overlayfs/rw"
+wait_for_dev -n "${OVERLAY_BASE}/overlayfs/work"
 
 return 0
