@@ -63,7 +63,7 @@ class DiskSetup:
         self.root_dir = root_dir
         self.xml_state = xml_state
 
-    def get_disksize_mbytes(self):  # noqa C901
+    def get_disksize_mbytes(self):
         """
         Precalculate disk size requirements in mbytes
 
@@ -193,10 +193,9 @@ class DiskSetup:
             return True
         if self.volume_manager == 'btrfs':
             return False
-        if self.filesystem == 'xfs':
-            return True
         if self.root_filesystem_is_overlay:
             return True
+        return False
 
     def get_boot_label(self):
         """
