@@ -277,6 +277,37 @@ class TestBootLoaderConfigBase:
         assert self.bootloader.get_gfxmode('some-loader') == \
             mock_get_vga.return_value
 
+    @patch('kiwi.bootloader.config.base.MountManager')
+    def test_mount_system_s390(self, mock_MountManager):
+        tmp_mount = MagicMock()
+        proc_mount = MagicMock()
+        dev_mount = MagicMock()
+        root_mount = MagicMock()
+        root_mount.mountpoint = 'root_mount_point'
+        root_mount.device = 'rootdev'
+        boot_mount = MagicMock()
+        boot_mount.device = 'bootdev'
+
+        mount_managers = [
+            proc_mount, dev_mount, tmp_mount, boot_mount, root_mount
+        ]
+
+        def mount_managers_effect(**args):
+            return mount_managers.pop()
+
+        self.bootloader.arch = 's390x'
+
+        mock_MountManager.side_effect = mount_managers_effect
+        self.bootloader._mount_system(
+            'rootdev', 'bootdev'
+        )
+        assert mock_MountManager.call_args_list == [
+            call(device='rootdev'),
+            call(device='bootdev', mountpoint='root_mount_point/boot/zipl'),
+            call(device='/dev', mountpoint='root_mount_point/dev'),
+            call(device='/proc', mountpoint='root_mount_point/proc')
+        ]
+
     @patch('kiwi.bootloader.config.base.MountManager')
     def test_mount_system(self, mock_MountManager):
         tmp_mount = MagicMock()
