@@ -41,7 +41,7 @@ class TestLiveImageBuilder:
         )
 
         self.bootloader = mock.Mock()
-        kiwi.builder.live.BootLoaderConfig = mock.Mock(
+        kiwi.builder.live.BootLoaderConfig.new = mock.Mock(
             return_value=self.bootloader
         )
 
@@ -170,6 +170,7 @@ class TestLiveImageBuilder:
         )
         mock_size.return_value = rootsize
 
+        self.setup.export_package_changes.return_value = '.changes'
         self.setup.export_package_verification.return_value = '.verified'
         self.setup.export_package_list.return_value = '.packages'
 
@@ -221,7 +222,7 @@ class TestLiveImageBuilder:
             config_file='root_dir/etc/dracut.conf.d/02-livecd.conf'
         )
 
-        kiwi.builder.live.BootLoaderConfig.assert_called_once_with(
+        kiwi.builder.live.BootLoaderConfig.new.assert_called_once_with(
             'grub2', self.xml_state, root_dir='root_dir',
             boot_dir='temp_media_dir', custom_args={
                 'grub_directory_name': 'grub2'
@@ -287,6 +288,13 @@ class TestLiveImageBuilder:
                 compress=False,
                 shasum=False
             ),
+            call(
+                key='image_changes',
+                filename='.changes',
+                use_for_bundle=True,
+                compress=True,
+                shasum=False
+            ),
             call(
                 key='image_verified',
                 filename='.verified',
@@ -304,9 +312,9 @@ class TestLiveImageBuilder:
 
         self.firmware.efi_mode.return_value = None
         tmpdir_name = ['temp-squashfs', 'temp_media_dir']
-        kiwi.builder.live.BootLoaderConfig.reset_mock()
+        kiwi.builder.live.BootLoaderConfig.new.reset_mock()
         self.live_image.create()
-        kiwi.builder.live.BootLoaderConfig.assert_called_once_with(
+        kiwi.builder.live.BootLoaderConfig.new.assert_called_once_with(
             'isolinux', self.xml_state, root_dir='root_dir',
             boot_dir='temp_media_dir'
         )
