@@ -15,22 +15,22 @@ class TestSolverRepository:
 
     def test_solver_repository_type_not_implemented(self):
         with raises(KiwiSolverRepositorySetupError):
-            SolverRepository(self.uri)
+            SolverRepository.new(self.uri)
 
-    @patch('kiwi.solver.repository.SolverRepositorySUSE')
+    @patch('kiwi.solver.repository.suse.SolverRepositorySUSE')
     def test_solver_repository_suse(self, mock_suse):
         self.uri.repo_type = 'yast2'
-        SolverRepository(self.uri)
+        SolverRepository.new(self.uri)
         mock_suse.assert_called_once_with(self.uri, None, None)
 
-    @patch('kiwi.solver.repository.SolverRepositoryRpmMd')
+    @patch('kiwi.solver.repository.rpm_md.SolverRepositoryRpmMd')
     def test_solver_repository_rpm_md(self, mock_rpm_md):
         self.uri.repo_type = 'rpm-md'
-        SolverRepository(self.uri)
+        SolverRepository.new(self.uri)
         mock_rpm_md.assert_called_once_with(self.uri, None, None)
 
-    @patch('kiwi.solver.repository.SolverRepositoryRpmDir')
+    @patch('kiwi.solver.repository.rpm_dir.SolverRepositoryRpmDir')
     def test_solver_repository_rpm_dir(self, mock_rpm_dir):
         self.uri.repo_type = 'rpm-dir'
-        SolverRepository(self.uri)
+        SolverRepository.new(self.uri)
         mock_rpm_dir.assert_called_once_with(self.uri, None, None)
